local mod = ...



-- Balancing -------------------------------------------------------------------------------------
mod:overrideAsset({
    Id = "DEFAULT_BALANCING",
    StartingTileResourceRequirement = {
        {
            Resource = "BERRIES",
            Quantity = 2
        },
        {
            Resource = "STONE",
            Quantity = 2
        },
        {
            Resource = "WOOD",
            Quantity = 50
        },
    },
    -- PlantableList = {
    --     Action = "APPEND",
    --     "PLANTABLE_PREFAB_CM_BERRY1",
    --     "PLANTABLE_PREFAB_CM_BERRY2",
    --     "PLANTABLE_PREFAB_CM_SAPLING1",
    --     "PLANTABLE_PREFAB_CM_SAPLING2",
    --     "PLANTABLE_PREFAB_CM_SAPLING3",
    --     "PLANTABLE_PREFAB_CM_SAPLING4",
    --     "PLANTABLE_PREFAB_CM_SAPLING5",
    --     "PLANTABLE_PREFAB_CM_BUSH1",
    --     "PLANTABLE_PREFAB_CM_BUSH2",
    --     "PLANTABLE_PREFAB_CM_BUSH3",
    --     "PLANTABLE_PREFAB_CM_BUSH4",
    --     "PLANTABLE_PREFAB_CM_BUSH5",
    -- }
})

mod:overrideAsset({
    Id = "BUILDING_FUNCTION_FORESTER",
    PlantableAssetList = {
        Action = "APPEND",
        "PLANTABLE_PREFAB_CM_BERRY1",
        "PLANTABLE_PREFAB_CM_BERRY2",
        "PLANTABLE_PREFAB_CM_SAPLING1",
        "PLANTABLE_PREFAB_CM_SAPLING2",
        "PLANTABLE_PREFAB_CM_SAPLING3",
        "PLANTABLE_PREFAB_CM_SAPLING4",
        "PLANTABLE_PREFAB_CM_SAPLING5",
        "PLANTABLE_PREFAB_CM_BUSH1",
        "PLANTABLE_PREFAB_CM_BUSH2",
        "PLANTABLE_PREFAB_CM_BUSH3",
        "PLANTABLE_PREFAB_CM_BUSH4",
        "PLANTABLE_PREFAB_CM_BUSH5",
    },
})



-- Vegetation and Stones -------------------------------------------------------------------------------------
function registerPlant(meshName, prefabName, resourceName, plantingDistance, radiusDistance, resourceQty, availableQty)

    mod:registerAssetId("models/Bush1.fbx/Prefab/" .. meshName, prefabName)
    mod:registerPrefabComponent("models/Bush1.fbx/Prefab/" .. meshName, { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = plantingDistance })
    mod:registerPrefabComponent("models/Bush1.fbx/Prefab/" .. meshName, { DataType = "COMP_TREE" })

    mod:registerAsset({
        DataType = "PLANTABLE",
        Id = "PLANTABLE_" .. prefabName,
        Name = "PLANTABLE_" .. prefabName,
        PlantPrefab = prefabName,
        Icon = "ICON_RESOURCE_" .. resourceName,
        MinimumScale = 0.85, -- min size at full growth
        MaximumScale = 1.15 -- max size at full growth
    })

    mod:registerPrefabComponent( "models/Bush1.fbx/Prefab/" .. meshName, {
        DataType = "COMP_RESOURCE_CONTAINER",
        ResourceData = resourceName,
        IsReplenishable = false,
        ResourceValue = resourceQty, -- how many are gathered with each pick
        AvailableQuantity = availableQty, -- maximum container stock
        Radius = radiusDistance, -- distance from container that the villager will stand to pick
        IsDestroyWhenEmpty = true,
    })    
    
end

registerPlant("Bush.001", "PREFAB_CM_BUSH1", "WOOD", 2, 1.2, 0.25, 1)
registerPlant("Bush.002", "PREFAB_CM_BUSH2", "WOOD", 2, 1.2, 0.25, 1)
registerPlant("Bush.003", "PREFAB_CM_BUSH3", "WOOD", 2, 1.2, 0.25, 1)
registerPlant("Bush.004", "PREFAB_CM_BUSH4", "WOOD", 2, 1.2, 0.25, 1)
registerPlant("Bush.005", "PREFAB_CM_BUSH5", "WOOD", 2, 1.2, 0.25, 1)
registerPlant("Sapling.001", "PREFAB_CM_SAPLING1", "WOOD", 2, 1.2, 0.5, 1)
registerPlant("Sapling.002", "PREFAB_CM_SAPLING2", "WOOD", 2, 1.2, 0.5, 1)
registerPlant("Sapling.003", "PREFAB_CM_SAPLING3", "WOOD", 2, 1.2, 0.5, 1)
registerPlant("Sapling.004", "PREFAB_CM_SAPLING4", "WOOD", 2, 1.2, 0.5, 1)
registerPlant("Sapling.005", "PREFAB_CM_SAPLING5", "WOOD", 2, 1.2, 0.5, 1)
registerPlant("Stone.001", "PREFAB_CM_STONE1", "STONE", 1, 1.2, 1, 10)
registerPlant("Stone.002", "PREFAB_CM_STONE2", "STONE", 1, 1.2, 1, 14)
registerPlant("Stone.003", "PREFAB_CM_STONE3", "STONE", 1, 1.2, 1, 8)
registerPlant("Stone.004", "PREFAB_CM_STONE4", "STONE", 1, 1.2, 1, 10)
registerPlant("Stone.005", "PREFAB_CM_STONE5", "STONE", 1, 1.2, 1, 16)



-- Berry Bushes -------------------------------------------------------------------------------------
function registerBerry(meshName, prefabName, resourceName, plantingDistance, radiusDistance, resourceQty, availableQty)

    mod:registerAssetId("models/Bush1.fbx/Prefab/" .. meshName, prefabName)
    mod:registerPrefabComponent("models/Bush1.fbx/Prefab/" .. meshName, { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = plantingDistance })
    mod:registerPrefabComponent("models/Bush1.fbx/Prefab/" .. meshName, { DataType = "COMP_TREE" })

    mod:registerAsset({
        DataType = "PLANTABLE",
        Id = "PLANTABLE_" .. prefabName,
        Name = "PLANTABLE_" .. prefabName,
        PlantPrefab = prefabName,
        Icon = "ICON_RESOURCE_" .. resourceName,
        MinimumScale = 0.85, -- min size at full growth
        MaximumScale = 1.15 -- max size at full growth
    })

    mod:registerPrefabComponent( "models/Bush1.fbx/Prefab/" .. meshName, {
        DataType = "COMP_RESOURCE_CONTAINER",
        ResourceData = resourceName,
        IsReplenishable = true,
        ReplenishDurationInDays = 7,
        ReplenishQuantity = availableQty,
        ResourceValue = resourceQty, -- how many are gathered with each pick
        AvailableQuantity = availableQty, -- maximum container stock
        Radius = radiusDistance, -- distance from container that the villager will stand to pick
        IsDestroyWhenEmpty = false,
    })    
    
end

registerBerry("BerryBush.001", "PREFAB_CM_BERRY1", "BERRIES", 2, 1.2, 2, 10)
registerBerry("BerryBush.002", "PREFAB_CM_BERRY2", "BERRIES", 2, 1.2, 2, 10)



-- Fertility inhibitor -------------------------------------------------------------------------------------
mod:registerAssetId("models/Bush1.fbx/Prefab/Blank", "PREFAB_CM_BLANK")
mod:registerPrefabComponent("models/Bush1.fbx/Prefab/Blank", { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = 20 })
mod:registerPrefabComponent("models/Bush1.fbx/Prefab/Blank", { DataType = "COMP_TREE" })

mod:registerAsset({
    DataType = "PLANTABLE",
    Id = "PLANTABLE_BLANK",
    Name = "PLANTABLE_BLANK_NAME",
    PlantPrefab = "PREFAB_CM_BLANK",
    Icon = "ICON_RESOURCE_WOOD",
    MinimumScale = 1, -- min size at full growth
    MaximumScale = 1 -- max size at full growth
})

mod:registerPrefabComponent( "models/Bush1.fbx/Prefab/Blank", {
    DataType = "COMP_RESOURCE_CONTAINER",
    ResourceData = "WATER",
    IsReplenishable = false,
    ResourceValue = 0, -- how many are gathered with each pick
    AvailableQuantity = 0, -- maximum container stock
    Radius = 1.25, -- distance from container that the villager will stand to pick
    IsDestroyWhenEmpty = true,
})    



-- -- Shipwreck and Ruins -------------------------------------------------------------------------------------
-- mod:registerAssetId("models/ShipWreck1.fbx/Prefab/Ship.001", "PREFAB_CM_SHIPWRECK1")
-- mod:registerAssetId("models/ShipWreck1.fbx/Prefab/Ruin.001", "PREFAB_CM_RUIN1")

-- mod:registerPrefabComponent( "models/ShipWreck1.fbx/Prefab/Ship.001", {
--     DataType = "COMP_RESOURCE_CONTAINER",
--     ResourceData = "RESOURCE_SALVAGE_SHIP",
--     IsReplenishable = false,
--     ResourceValue = 2, -- how many are gathered with each pick
--     AvailableQuantity = 500, -- maximum container stock
--     Radius = 5.0, -- distance from container that the villager will stand to pick
--     IsDestroyWhenEmpty = true,
-- })    

-- mod:registerPrefabComponent( "models/ShipWreck1.fbx/Prefab/Ruin.001", {
--     DataType = "COMP_RESOURCE_CONTAINER",
--     ResourceData = "RESOURCE_SALVAGE_RUIN",
--     IsReplenishable = false,
--     ResourceValue = 2, -- how many are gathered with each pick
--     AvailableQuantity = 200, -- maximum container stock
--     Radius = 5.0, -- distance from container that the villager will stand to pick
--     IsDestroyWhenEmpty = true,
-- })    

-- mod:registerAssetId("icons/Salvage.png", "ICON_RESOURCE_SALVAGE", "ATLAS_CELL")

-- mod:registerAsset({
-- 	DataType = "RESOURCE",
-- 	Id = "RESOURCE_SALVAGE_SHIP",
-- 	ResourceName = "RESOURCE_SALVAGE_NAME",
-- 	Icon = "ICON_RESOURCE_SALVAGE",
-- 	ResourceTypeList = { "RESOURCE" },
-- 	IsTradable = false,
--     OrderId = 982,
-- })

-- mod:registerAsset({
-- 	DataType = "RESOURCE",
-- 	Id = "RESOURCE_SALVAGE_RUIN",
-- 	ResourceName = "RESOURCE_SALVAGE_NAME",
-- 	Icon = "ICON_RESOURCE_SALVAGE",
-- 	ResourceTypeList = { "RESOURCE" },
-- 	IsTradable = false,
--     OrderId = 983,
-- })

-- mod:registerAsset({
--     DataType = "BUILDING_FUNCTION_WORKPLACE",
--     Id = "BUILDING_FUNCTION_CM_SHIPWRECK",
--     Name = "BUILDING_FUNCTION_CM_SHIPWRECK_NAME",
--     WorkerCapacity = 3,
--     RelatedJob = { 
--         Job = "JOB_CM_SHIPWRECK", 
--         Behavior = "BEHAVIOR_GATHER"
--     },
--     InputInventoryCapacity = {
-- 		{ Resource = "RESOURCE_SALVAGE_SHIP", Quantity = 1 },
-- 	},
--     ResourceListNeeded = {
-- 		{ Resource = "RESOURCE_SALVAGE_SHIP", Quantity = 1 },
-- 	},
--     ResourceProduced = {
-- 		{ Resource = "PLANK", Quantity = 5 },
-- 		{ Resource = "GOLD_COINS", Quantity = 10 },
-- 		{ Resource = "CLOTHES", Quantity = 1 },
-- 		{ Resource = "BARREL", Quantity = 1 },
-- 		{ Resource = "IRON", Quantity = 1 },
-- 		{ Resource = "TOOL", Quantity = 1 },
-- 		{ Resource = "WINE", Quantity = 1 },
-- 	}
-- })

-- mod:registerAsset({
--     DataType = "BUILDING_FUNCTION_WORKPLACE",
--     Id = "BUILDING_FUNCTION_CM_RUIN",
--     Name = "BUILDING_FUNCTION_CM_RUIN_NAME",
--     WorkerCapacity = 3,
--     RelatedJob = { 
--         Job = "JOB_CM_RUIN", 
--         Behavior = "BEHAVIOR_GATHER"
--     },
--     InputInventoryCapacity = {
-- 		{ Resource = "RESOURCE_SALVAGE_RUIN", Quantity = 1 },
-- 	},
--     ResourceListNeeded = {
-- 		{ Resource = "RESOURCE_SALVAGE_RUIN", Quantity = 1 },
-- 	},
--     ResourceProduced = {
-- 		{ Resource = "POLISHED_STONE", Quantity = 5 },
-- 		{ Resource = "STONE", Quantity = 5 },
-- 		{ Resource = "GOLD_COINS", Quantity = 10 },
-- 	}
-- })

-- mod:overrideAsset({
--     Id = "BUILDING_FUNCTION_LIST_LORD_MANOR",
--     AssetFunctionList = {
--         Action = "APPEND",
--         "BUILDING_FUNCTION_CM_SHIPWRECK",
--         "BUILDING_FUNCTION_CM_RUIN",
--     }
-- })

-- mod:registerAsset({
-- 	DataType = "JOB",
-- 	Id = "JOB_CM_SHIPWRECK",
-- 	JobName = "JOB_CM_SHIPWRECK_NAME",
-- 	JobDescription = "JOB_CM_SHIPWRECK_DESC",
-- 	IsLockedByDefault = true,
-- 	DefaultBehavior = "BEHAVIOR_GATHER",
--     ProductionDelay = 30.0,
-- 	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
-- 	CharacterSetup = {
-- 		DataType = "CHARACTER_SETUP",
-- 		WalkAnimation = "WALKING",
-- 		IdleAnimation = "LUMBERING"
-- 	}
-- })

-- mod:overrideAsset({
--     Id = "NEWCOMER",
--     CompatibleJobList = {
--         Action = "APPEND",
--         "JOB_CM_SHIPWRECK"
--     }
-- })

-- mod:overrideAsset({
--     Id = "SERF",
--     CompatibleJobList = {
--         Action = "APPEND",
--         "JOB_CM_SHIPWRECK"
--     }
-- })

-- mod:overrideAsset({
--     Id = "COMMONER",
--     CompatibleJobList = {
--         Action = "APPEND",
--         "JOB_CM_SHIPWRECK"
--     }
-- })

-- mod:registerAsset({
-- 	DataType = "JOB",
-- 	Id = "JOB_CM_RUIN",
-- 	JobName = "JOB_CM_RUIN_NAME",
-- 	JobDescription = "JOB_CM_RUIN_DESC",
-- 	IsLockedByDefault = true,
-- 	DefaultBehavior = "BEHAVIOR_GATHER",
--     ProductionDelay = 30.0,
-- 	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
-- 	CharacterSetup = {
-- 		DataType = "CHARACTER_SETUP",
-- 		WalkAnimation = "WALKING",
-- 		IdleAnimation = "MINE"
-- 	}
-- })

-- mod:overrideAsset({
--     Id = "NEWCOMER",
--     CompatibleJobList = {
--         Action = "APPEND",
--         "JOB_CM_RUIN"
--     }
-- })

-- mod:overrideAsset({
--     Id = "SERF",
--     CompatibleJobList = {
--         Action = "APPEND",
--         "JOB_CM_RUIN"
--     }
-- })

-- mod:overrideAsset({
--     Id = "COMMONER",
--     CompatibleJobList = {
--         Action = "APPEND",
--         "JOB_CM_RUIN"
--     }
-- })



-- Materials -------------------------------------------------------------------------------------
mod:registerAssetId("models/Bush1.fbx/Materials/Material.Bush1", "MATERIAL_CM_BUSH1")
mod:registerAssetId("models/Bush1.fbx/Materials/Material.Bush2", "MATERIAL_CM_BUSH2")
mod:registerAssetId("models/Bush1.fbx/Materials/Material.Bush3", "MATERIAL_CM_BUSH3")
mod:registerAssetId("models/Bush1.fbx/Materials/Material.Tree1", "MATERIAL_CM_TREE1")

mod:overrideAsset({ Id = "MATERIAL_CM_BUSH1", HasAlphaTest = true, })
mod:overrideAsset({ Id = "MATERIAL_CM_BUSH2", HasAlphaTest = true, })
mod:overrideAsset({ Id = "MATERIAL_CM_BUSH3", HasAlphaTest = true, })
mod:overrideAsset({ Id = "MATERIAL_CM_TREE1", HasAlphaTest = true, })



-- register map files -------------------------------------------------------------------------------------
mod:registerAssetId("maps/heightmap.png", "HEIGHT_MAP")
mod:registerAssetId("maps/material_mask.png", "MATERIAL_MASK")
mod:registerAssetId("maps/berries_density.png", "BERRIES_DENSITY_MAP")
mod:registerAssetId("maps/rock_density.png", "ROCK_DENSITY_MAP")
mod:registerAssetId("maps/fish_density.png", "FISH_DENSITY_MAP")
mod:registerAssetId("maps/infertility_density.png", "INFERTILITY_MAP")
mod:registerAssetId("maps/bush_density.png", "BUSH_MAP")
mod:registerAssetId("maps/tree_density.png", "TREE_MAP")
mod:registerAssetId("maps/sapling_density.png", "SAPLING_MAP")
mod:registerAssetId("maps/stone_density.png", "STONE_MAP")



-- Register custom map
mod:registerAsset({
	DataType = "CUSTOM_MAP",
	Id = "MAP_CAPPOQUIN",
	HeightMap = "HEIGHT_MAP",
	MaterialMask = "MATERIAL_MASK",
	MinHeight = -12,
	MaxHeight = 50,
	VillagePathList = {
        {
            Entrance = { 56, 0, 1015 },
            Exit = { 4, 0, 174 },
        },
        {
            Entrance = { 300, 0, 1013 },
            Exit = { 1022, 0, 571 },
        },
        {
            Entrance = { 400, 0, 1013 },
            Exit = { 4, 0, 364 },
        },
        {
            Entrance = { 500, 0, 1013 },
            Exit = { 5, 0, 504 },
        },
        {
            Entrance = { 715, 0, 1018 },
            Exit = { 4, 0, 586 },
        },
        {
            Entrance = { 749, 0, 1013 },
            Exit = { 5, 0, 735 },
        },
        {
            Entrance = { 858, 0, 1015 },
            Exit = { 1021, 0, 646 },
        }
    },
	SpawnList = {
		-- {
		-- 	-- Wrecked ship
		-- 	Prefab = "PREFAB_CM_SHIPWRECK1",
		-- 	Position = { 330 , 10 , 198 },
		-- 	Orientation = { 0.0, 20.0 , 0.0},
		-- 	PatchBeforeVersion = "1.1.0"
		-- },
		-- {
		-- 	-- Caslte Ruin
		-- 	Prefab = "PREFAB_CM_RUIN1",
		-- 	Position = { 500, 22 , 310 },
		-- 	Orientation = { 0.0, 45.0 , 0.0},
		-- 	PatchBeforeVersion = "1.1.0"
		-- },

        {
			-- creating Mineral Deposit 1
			Prefab = "PREFAB_MINERAL_SOURCE_1",
			Position = { 110 , 6 , 118 },
			Orientation = { 0.0, -90.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 2
			Prefab = "PREFAB_MINERAL_SOURCE_2",
			Position = { 195 , 20 , 535 },
			Orientation = { 0.0, -100.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 3
			Prefab = "PREFAB_MINERAL_SOURCE_3",
			Position = { 114 , 24 , 752 },
			Orientation = { 0.0, -15.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 4
			Prefab = "PREFAB_MINERAL_SOURCE_1",
			Position = { 480 , 4 , 796 },
			Orientation = { 0.0, -60.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 5
			Prefab = "PREFAB_MINERAL_SOURCE_2",
			Position = { 883 , 20 , 757 },
			Orientation = { 0.0, -25.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 6
			Prefab = "PREFAB_MINERAL_SOURCE_3",
			Position = { 599 , 16 , 599 },
			Orientation = { 0.0, 55.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 7
			Prefab = "PREFAB_MINERAL_SOURCE_1",
			Position = { 510 , 26 , 599 },
			Orientation = { 0.0, -65.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 8
			Prefab = "PREFAB_MINERAL_SOURCE_2",
			Position = { 354 , 17 , 498 },
			Orientation = { 0.0, 170.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
	},
    DensitySpawnList = {

		{
			-- Infertility (farms will never grow crops here)
			DensityMap = "INFERTILITY_MAP",
			Density = 1.0,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_CM_BLANK" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 1.0,
                        Max = 1.0
                    },
                    OrientationRange = {
                        Min = { 0, 0, 0 },
                        Max = { 0, 0, 0 }
                    },
                    ScaleRange = {
                        Min = 1,
                        Max = 1
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                }
			}
		},

		{
			-- Bushes (small amount of wood, inhibits farming until cleared)
			DensityMap = "BUSH_MAP",
			Density = 0.5,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_CM_BUSH1" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.50,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_BUSH2" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.50,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_BUSH3" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.50,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_BUSH4" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.50,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_BUSH5" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.50,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_BERRY1" },
                    RandomWeight = 0.3,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 1.0,
                        Max = 1.1,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_BERRY2" },
                    RandomWeight = 0.3,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 1.0,
                        Max = 1.1,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
			}
		},

        {
			-- Saplings (small amount of wood, inhibits farming until cleared)
			DensityMap = "SAPLING_MAP",
			Density = 0.7,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_CM_SAPLING1" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.75,
                        Max = 1.25,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_SAPLING2" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.75,
                        Max = 1.25,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_SAPLING3" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.75,
                        Max = 1.25,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_SAPLING4" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.75,
                        Max = 1.25,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_SAPLING5" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.75,
                        Max = 1.25,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
			}
		},

        {
			-- Trees
			DensityMap = "TREE_MAP",
			Density = 0.8,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_TREE_OAK" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_TREE_POPLAR" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_TREE_SYCAMORE" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
			}
		},

        
		{
			-- Stones (small amount of stone, inhibits farming until cleared)
			DensityMap = "STONE_MAP",
			Density = 0.6,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_CM_STONE1" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_STONE2" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_STONE3" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_STONE4" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
				{
                    PrefabList = { "PREFAB_CM_STONE5" },
                    RandomWeight = 1.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.00,
                    },
                    OrientationRange = {
                        Min = { 0, -90, 0 },
                        Max = { 0, 90, 0 },
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15,
                    },
                    ColorRange = {
                        Min = { 1, 1, 1, 1 },
                        Max = { 1, 1, 1, 1 },
                    },
                },
			}
		},

        -- {
		-- 	-- Create rock outcrops - stone resource
		-- 	DensityMap = "ROCK_DENSITY_MAP",
		-- 	Density =0.9,
		-- 	PrefabConfigList = {
		-- 		{
		-- 				PrefabList = { "PREFAB_RESOURCE_ROCK" },
		-- 				RandomWeight = 0.1,
		-- 				OffsetSizeRange = {
		-- 					Min = 0.75,
		-- 					Max = 1.0
		-- 			},
		-- 				OrientationRange = {
		-- 					Min = { 0, -180, 0 },
		-- 					Max = { 0, 180, 0 }
		-- 			},
		-- 				ScaleRange = {
        --                     Min = 1.10,
        --                     Max = 1.20,
        --                 },
		-- 				ColorRange = {
		-- 					Min = { 0.8, 0.8, 0.8, 1 },
		-- 					Max = { 1, 1, 1, 1 }
		-- 			}
		-- 		}
		-- 	}
		-- },

        {
			-- Create fish shoals
			DensityMap = "FISH_DENSITY_MAP",
			Density = 0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_FISH" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		}
	}
})
-- This map was created with the help of the UFME
